﻿using UnityEngine;
using System.Collections;

public class EnemyBehavior : MonoBehaviour {

	//This controls the speed at which we want our "projectile" to shoot from our Enemy ships.
	public float enemyProjectileSpeed = 10f;
	
	//This allows us to specify the sprite for the laser we want to use for our Enemies by dragging it to the Enemy Blue Laser prefab in the Inspector.
	public GameObject enemyProjectile;

	//Used to initially set the damage that a projectile in our game is caused by our Enemy ships.
	//It can be made public for testing while using the Inspector.
	private float health = 200f;
	
	//We use this to create a more random feel to the shots being fired by our Enemy ships as part of a probability formula.
	private float shotsPerSecond = 0.5f;
	
	//This method detects a collision with our enemy ships' collider from another object collider.
	void OnTriggerEnter2D(Collider2D collider)  {
		//Used for debugging.
		//TODO:  Remove before production release.
		print ("Collision");
		
		//We call upon the Projectiles class to create an instance of a projectile so we can use it to detect collision with our enemy ships.
		Projectiles missile = collider.gameObject.GetComponent<Projectiles>();
				
		//If that projectile exists in the game space, then decrease the health of the Player ship that is hit by the damage returned by the projectile.
		//Run the Hit method of the projectile for any specific projectile properties to be run.
		//If our Player ship's health is less than or equal to 0, then destroy it.
		if (missile) {
			//Used for debugging.
			//TODO:  Remove before production release.
			print ("Hit by projectile");
			
			//Calculate the health of our Player ship by taking its current health and subtracting it from the value returned of the GetDamage() method called from the Projectiles class.
			health -= missile.GetDamage();
			
			//This removes the projectile from the game space since we obviously collided with our Player ship.
			missile.Hit();
			
			//We determine if our Player ship's health is less than or equal to zero; if it is, then we destroy the Player ship.
			if (health <= 0) {
				Destroy(gameObject);
			}
		}
	}
	
	void Update() {
		
		//This is used to create the random firing effect of our Enemy ships to make our game more interesting.
		//Probability is always between 0 and 1.
		float probability = Time.deltaTime * shotsPerSecond;
		
		//Here we take a random value between 0 and 1 and check to see if it is less than our probability value.
		//If it is, then we run our enemyFireProjectile() method which is what causes the laser to fire.
		if (Random.value < probability) {
			enemyFireProjectile();
		}
		
		
	}
	
	//This method is used to actually fire the projectile from the Enemy ships with our enemyProjectileSpeed value.
	void enemyFireProjectile() {
		//Create a start position for the enemy laser prefab that is -0.5f down on the Y axis from the enemy prefab's position.
		//We do this because the laser starting at the same position of the Enemy ship causes it to take damage immediately and die.
		//We could use layers here to make it easier, but this works for now.
		Vector3 startPosition = transform.position + new Vector3(0, -0.5f, 0);
		
		//We instantiate the actual Enemy Blue Laser prefab and assign the velocity equal to that of our enemyProjectileSpeed.
		//We need this to be a negative value because we want the laser to shoot down from the Enemy ships.
		GameObject enemyLaser = Instantiate(enemyProjectile, startPosition, Quaternion.identity) as GameObject;
		enemyLaser.rigidbody2D.velocity = new Vector3 (0, -enemyProjectileSpeed, 0);
		
	}
}
